#!/usr/bin/env python
# -*- coding: utf-8 -*-
# ElbiaAdmin Python-lib version 2.1.8
# Copyright (c) 2010-2022, Jozef Sudolsky, ELBIA, s. r. o. (jozef@sudolsky.sk)
# All rights reserved.
# BSD Licence
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
#     1. Redistributions of source code must retain the above copyright notice,
#        this list of conditions and the following disclaimer.
#
#     2. Redistributions in binary form must reproduce the above copyright
#        notice, this list of conditions and the following disclaimer in the
#        documentation and/or other materials provided with the distribution.
#
#     3. Neither the name of ElbiaAdmin Python-lib nor the names of its
#        contributors may be used to endorse or promote products derived from
#        this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
################################################################################
"""
EXAMPLE EXAMPLE EXAMPLE EXAMPLE EXAMPLE EXAMPLE EXAMPLE EXAMPLE EXAMPLE EXAMPLE
EXAMPLE EXAMPLE EXAMPLE EXAMPLE EXAMPLE EXAMPLE EXAMPLE EXAMPLE EXAMPLE EXAMPLE
EXAMPLE EXAMPLE EXAMPLE EXAMPLE EXAMPLE EXAMPLE EXAMPLE EXAMPLE EXAMPLE EXAMPLE

import ealibNIC

ean = ealibNIC.ElbiaAdminNIC("login", "password")


result = ean.domain_info("inetadmin", "eu")

print result


result = ean.domain_info_bulk(["inetadmin", "test", "fegre"])

print result


result = ean.transfer_domain_request("inetadmin", "eu",  "auth-id")

print result


result = ean.create_domain_request("example", "sk", {"hosts": [{"host": "ns.inetadmin.eu"}, {"host": "ns.inetadmin.sk"}, {"host": "ns.inetadmin.cz"}]}, {"registrant": {"regid": "ELBIA"}, "tech": {"regid": "ELBIA"}, "admin": {"regid": "ELBIA"}})

print result
"""
################################################################################
import base64
import time
import datetime

import ealibCore

class ElbiaAdminNIC(ealibCore.ElbiaAdmin):

	OK_STATE = "ok"

	def domain_info(self, domain, tld):
		return self._do_command("domain_info", (domain, tld), "N", True, False)

	def domain_info_bulk(self, domains):
		return self._do_command("domain_info_bulk", (self.__token__, domains), "N")

	def check_domain(self, domain, tld):
		return self._do_command("check_domain", (domain, tld), "N", True, False)

	def user_info(self, nicid):
		return self._do_command("user_info", (nicid,), "N", True, False)

	def get_requests(self, poffset, pcount, fid=None, fdomain=None, ftld=None, ftype=None, fstate=None):
		result = self._do_command("get_requests", (self.__token__, poffset, pcount, fid, fdomain, ftld, ftype, fstate), "N")
		if result["state"] == self.OK_STATE:
			for i in xrange(len(result["data"])):
				result["data"][i]["dateadd"] = datetime.datetime.fromtimestamp(time.mktime(time.strptime(result["data"][i]["dateadd"], "%H:%M:%S %d.%m.%Y")))
				result["data"][i]["dateok"] = datetime.datetime.fromtimestamp(time.mktime(time.strptime(result["data"][i]["dateok"], "%H:%M:%S %d.%m.%Y")))
		return result

	def get_request(self, req_id):
		result = self._do_command("get_request", (self.__token__, req_id), "N")
		if result["state"] == self.OK_STATE:
			result["data"]["dateadd"] = datetime.datetime.fromtimestamp(time.mktime(time.strptime(result["data"]["dateadd"], "%H:%M:%S %d.%m.%Y")))
			if result["data"]["dateok"]:
				result["data"]["dateok"] = datetime.datetime.fromtimestamp(time.mktime(time.strptime(result["data"]["dateok"], "%H:%M:%S %d.%m.%Y")))
		return result

	def backorder_domain_request(self, domain, tld, registrant):
		return self._do_command("backorder_domain_request", (self.__token__, domain, tld, registrant), "N")

	def get_backorders(self, poffset, pcount, fdomain=None, fowner=None, fstate=None):
		result = self._do_command("get_backorders", (self.__token__, poffset, pcount, fdomain, fowner, fstate), "N")
		if result["state"] == self.OK_STATE:
			for i in xrange(len(result["data"])):
				result["data"][i]["dateadd"] = datetime.date.fromtimestamp(time.mktime(time.strptime(result["data"][i]["dateadd"], "%d.%m.%Y")))
				result["data"][i]["dateok"] = datetime.date.fromtimestamp(time.mktime(time.strptime(result["data"][i]["dateok"], "%d.%m.%Y")))
		return result

	def get_backorder(self, req_id):
		result = self._do_command("get_backorder", (self.__token__, req_id), "N")
		if result["state"] == self.OK_STATE:
			result["data"]["dateadd"] = datetime.date.fromtimestamp(time.mktime(time.strptime(result["data"]["dateadd"], "%d.%m.%Y")))
			result["data"]["dateok"] = datetime.date.fromtimestamp(time.mktime(time.strptime(result["data"]["dateok"], "%d.%m.%Y")))
		return result

	def backorder_cancel(self, req_id):
		return self._do_command("backorder_cancel", (self.__token__, req_id), "N")

	def expired_list(self):
		result = self._do_command("expired_list", (self.__token__,), "N")
		if result["state"] == self.OK_STATE:
			for i in xrange(len(result["data"])):
				result["data"][i]["date"] = datetime.date.fromtimestamp(time.mktime(time.strptime(result["data"][i]["date"], "%d.%m.%Y")))
		return result

	def get_domains(self, poffset, pcount, fdomain=None, ftld=None, fexpirationfrom=None, fexpirationto=None):
		return self._do_command("get_domains", (self.__token__, poffset, pcount, fdomain, ftld, fexpirationfrom, fexpirationto), "N")

	def poll_message(self):
		return self._do_command("poll_message", (self.__token__,), "N")

	def ack_message(self, message_id):
		return self._do_command("ack_message", (self.__token__, message_id), "N")

	def get_waiting_payments(self, poffset, pcount, fdomain=None, ftld=None):
		return self._do_command("get_waiting_payments", (self.__token__, poffset, pcount, fdomain, ftld), "N")

	def get_domain_move_password(self, domain, tld, password):
		return self._do_command("get_domain_move_password", (self.__token__, domain, tld, password), "N")

	def move_domain(self, domain, tld, password):
		return self._do_command("move_domain", (self.__token__, domain, tld, password), "N")

	def register_nsset_cz_request(self, name, tech, ns1, ns2, ns3=None, ns4=None, ip1=None, ip2=None, ip3=None, ip4=None, ipv6_1=None, ipv6_2=None, ipv6_3=None, ipv6_4=None):
		return self._do_command("register_nsset_cz_request", (self.__token__, name, tech, ns1, ns2, ns3, ns4, ip1, ip2, ip3, ip4, ipv6_1, ipv6_2, ipv6_3, ipv6_4), "N")

	def get_contacts(self, poffset, pcount, fname=None, ftld=None):
		result = self._do_command("get_contacts", (self.__token__, poffset, pcount, fname, ftld), "N")
		return result

	def get_contact(self, cid):
		result = self._do_command("get_contact", (self.__token__, cid), "N")
		return result

	def create_contact_request(self, tld, contacts):
		return self._do_command("create_contact_request", (self.__token__, tld, contacts), "N")

	def modify_contact_request(self, cid, contacts):
		return self._do_command("modify_contact_request", (self.__token__, cid, contacts), "N")

	def create_domain_request(self, domain, tld, nss, contacts):
		if "hosts" in nss:
			nss["hosts"] = {"nss_hosts_request": nss["hosts"]}
		return self._do_command("create_domain_request", (self.__token__, domain, tld, nss, contacts), "N")

	def renew_domain_request(self, domain, tld):
		return self._do_command("renew_domain_request", (self.__token__, domain, tld), "N")

	def modify_ns_request(self, domain, tld, nss):
		if "hosts" in nss:
			nss["hosts"] = {"nss_hosts_request": nss["hosts"]}
		return self._do_command("modify_ns_request", (self.__token__, domain, tld, nss), "N")

	def modify_domain_request(self, domain, tld, contacts):
		return self._do_command("modify_domain_request", (self.__token__, domain, tld, contacts), "N")

	def transfer_domain_request(self, domain, tld, authid, contacts):
		return self._do_command("transfer_domain_request", (self.__token__, domain, tld, authid, contacts), "N")

	def send_authid_request(self, domain, tld):
		return self._do_command("send_authid_request", (self.__token__, domain, tld), "N")

	def set_domain_autorenew(self, domain, tld, value):
		return self._do_command("set_domain_autorenew", (self.__token__, domain, tld, value), "N")
